Lua_HeroReshapeWindow = class("Lua_HeroReshapeWindow", Lua_Window);
function Lua_HeroReshapeWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_HeroReshapeWindow";
	self.skinName = "HeroReshapeWindow_skin";
	self.isClickClose = true;
	self.showBlackMask = true;
end

function Lua_HeroReshapeWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.itemList = Lua_DragList.new(self.content, 623, 234, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(8, -15, 0);
	self.itemList:setListCell(Lua_HeroReshapeItemCell, 112, 112, 5);
	self.itemList:setCellSpacing(12, 15);
	-- self.itemList.tweenId = 2003;
	-- self.itemList.delayTween = true;

	self.remianTimes = DataCenter.heroUtil.rollback_num - DataCenter.heroAssemblyData.rollbackTime;

	self.tipIcon:addClickFuntion(self, self.onTipTconClick);
	self.btnReshape:addClickFuntion(self, self.onReshapeClick);

	self:addLuaEvent("UPDATE_HERO_RESHAPE_INFO", self, self.showItemInfo);
end

function Lua_HeroReshapeWindow:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.costIconItem ~= nil then
		self.costIconItem:dispose()
		self.costIconItem = nil;
	end
	self:superCall("dispose");
end

function Lua_HeroReshapeWindow:showWin(param)
	self:superCall("showWin", param);
	local heroVo = Lua_HeroVo.new(param.id);
	heroVo.quality = self.showData.quality;
	heroVo.quality_star = self.showData.quality_star;

	self.remainTime = DataCenter.heroUtil.rollback_num - DataCenter.heroAssemblyData.rollbackTime;
	if self.remainTime < 0 then
		self.remainTime = 0;
	end
	local rate = DataCenter.heroUtil.rebuild_ratio * 100;
	self.tipTxt.text = LanUtil.formateStr(126425, tostring(heroVo.colorName), tostring(rate));

	local cfgData = DataCenter.heroUtil:getHeroAwakenStarConfigInfo(param.awaken_star_id);
	self.isUseFree = cfgData.use_free_rollback == 1;
	if self.remianTimes > 0 and self.isUseFree then
		self.promptTxt:setEnable(true);
		self.promptTxt.text = LanUtil.formateStr(126432, tostring(self.remianTimes));
		if self.costIconItem ~= nil then
			self.costIconItem:setEnable(false);
		end
	else
		self.promptTxt:setEnable(false);
		if self.costIconItem == nil then
			self.costIconItem = Lua_ConsumeIconItem.new(self.content);
			self.costIconItem:setLocation(0, -180, 0);
			self.costIconItem:setStyle(Lua_MyUISettings.defaultFontName, 22, "565656");

			self.costInfo = cfgData.rollback_consume;
			self.costIconItem:setData(self.costInfo);
		end
	end

	Lua_ProxyManager.getProxy("Lua_HeroAssemblyProxy"):sHeroReshapeItem(param.unique_id);
end

function Lua_HeroReshapeWindow:showItemInfo(msg)
	if msg == nil then
		return
	end

	local tab = DataCenter.packData:getRewardDic(msg.item_list);
    local arr = DataCenter.packData:getRewardList(tab); 
    if arr:getSize() > 0 then
    	local vo;
    	local siftInfo = DataCenter.heroUtil.siftInfo;
    	local campIdx;
    	for i = 1, arr:getSize() do
    		vo = arr[i];
    		if vo.main_type == Lua_PackDefine.HERO then -- 英雄
    			campIdx = siftInfo:indexOf(vo.campType);
    			vo.sort = vo.quality * 100 + vo.quality_star * 10 - campIdx;
    		elseif vo.main_type == Lua_PackDefine.EQUIP then -- 装备
    			vo.sort = -1000;
    		elseif vo.main_type == Lua_PackDefine.RUNES then -- 符石
    			vo.sort = -2000;
    		elseif vo.main_type == Lua_PackDefine.MATERIALS then -- 消耗材料
    			vo.sort = -3000;
    		else
    			vo.sort = -4000;
    		end
    	end
    	arr:sort("sort", true);
		self.itemList:setArrayData(arr);
	end
end

function Lua_HeroReshapeWindow:onTipTconClick(go)
	local param = { des = LanUtil.getValue(126435), posX = 180, posY = -375 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_HeroReshapeWindow:onReshapeClick(go)
	if (self.remianTimes > 0 and self.isUseFree) or (self.costInfo ~= nil and DataCenter.packData:getItemCountById(self.costInfo[1]) >= self.costInfo[2]) then
		Lua_ProxyManager.getProxy("Lua_HeroAssemblyProxy"):sHeroReshape(self.showData.unique_id);
		self:hide();
	else
		OperateAlert.showLangValue(126415);
	end
end





















Lua_HeroReshapeItemCell = class("Lua_HeroReshapeItemCell", Lua_ItemIconCell);
function Lua_HeroReshapeItemCell:buildShowItem()
    self:superCall("buildShowItem");
    self.itemIcon:setScale(0.9, 0.9, 0.9);
end
